==> haskell-hxt-unicode-9.0.2.4-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-7NUwe2RRpR3FIfA7kuOPqv
key:                  hxt-unicode-9.0.2.4-7NUwe2RRpR3FIfA7kuOPqv
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  b1fd2b288a2e06a5e6a5c230dc9a3c11
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-unicode
hs-libraries:         HShxt-unicode-9.0.2.4-7NUwe2RRpR3FIfA7kuOPqv
depends:
    base-4.16.4.0 hxt-charproperties-9.5.0.0-9g2utucZe333uNPQXZRzn0

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-unicode-9.0.2.4-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-8PDfOVqMrX87hvI0Mnbp0D
key:                  hxt-unicode-9.0.2.4-8PDfOVqMrX87hvI0Mnbp0D
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  4354b216a40dd1b3df45bbcd8f407eaf
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hxt-unicode-9.0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-unicode
hs-libraries:         HShxt-unicode-9.0.2.4-8PDfOVqMrX87hvI0Mnbp0D
depends:
    base-4.17.2.1 hxt-charproperties-9.5.0.0-JsuB8BVB3oQCkNkgJgjWcz

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
